@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import logging
 import aiohttp
 
 from typing import Any, List
@@ -14,8 +13,6 @@ from .exceptions import NotInitialized, Py2NError
 
 from .utils import get_info, get_status, restart, test_audio, get_switches, set_switch
 
-_LOGGER = logging.getLogger(__name__)
-
 
 class Py2NDevice:
     def __init__(self, aiohttp_session, options: Py2NConnectionData):
@@ -71,6 +68,7 @@ class Py2NDevice:
                 name=info["deviceName"],
                 model=info["variant"],
                 serial=info["serialNumber"],
+                host=self.options.ip_address,
                 mac=info["macAddr"],
                 firmware=f"{info['swVersion']}-{info['buildType']}",
                 hardware=info["hwVersion"],
@@ -120,11 +118,6 @@ class Py2NDevice:
     async def close(self) -> None:
         await self.aiohttp_session.close()
 
-    @property
-    def ip_address(self) -> str:
-        """Device ip address."""
-        return self.options.ip_address
-
     @property
     def data(self) -> Py2NDeviceData:
         """Get device data."""
