@@ -14,7 +14,7 @@ from typing import Optional
 class Py2NConnectionData:
     """Data for connection with 2N device."""
 
-    ip_address: str
+    host: str
     username: str | None = None
     password: str | None = None
     auth: aiohttp.BasicAuth | None = None
@@ -46,6 +46,7 @@ class Py2NDeviceData:
     name: str
     model: str
     serial: str
+    host: str
     mac: str
     firmware: str
     hardware: str
